@@ -7,7 +7,7 @@ use Carp 'carp';
 use v5.10.1;
 
 our @CARP_NOT;
-our $VERSION = '0.17';
+our $VERSION = '0.19';
 
 our $DEFAULT_KEY_SIZE = 512;
 our $MAX_GEN_ROUNDS = 100;
@@ -37,9 +37,6 @@ our @EXPORT_OK = qw(b64url_encode b64url_decode);
 # Primitive for Math::Prime::Util
 sub random_nbit_prime;
 
-# Primitive for Bytes::Random::Secure::random_bytes
-sub random_bytes;
-
 our $GENERATOR;
 
 # Load Math::Prime::Util and Math::Random::Secure
@@ -62,7 +59,7 @@ sub new {
   if (my $bl = blessed($_[0])) {
 
     # It's already a MagicKey object - fine!
-    return $_[0] if $bl eq __PACKAGE__;
+    return $_[0] if $bl->isa(__PACKAGE__);
   }
 
   # Do not support references
@@ -863,7 +860,7 @@ L<https://github.com/sivy/Salmon>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2016, L<Nils Diewald|http://nils-diewald.de/>.
+Copyright (C) 2012-2017, L<Nils Diewald|http://nils-diewald.de/>.
 
 This program is free software, you can redistribute it
 and/or modify it under the terms of the Artistic License version 2.0.
